@@ -6,8 +6,8 @@
 #include <string>
 #include <unordered_map>
 #include <vector>
-#include "ATen/core/interned_strings.h"
-#include "c10/util/Exception.h"
+#include <ATen/core/interned_strings.h>
+#include <c10/util/Exception.h>
 
 namespace c10 {
 
